==> criticizer-0.0.1-sources.jar: pl/michal/grzesiak/criticizer/ClassesProvider.java <==
package pl.michal.grzesiak.criticizer;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.List;

import static java.util.Collections.emptyEnumeration;
import static java.util.stream.Collectors.toList;

class ClassesProvider {

    private static final String JAVA_CLASS_EXTENSION = ".class";

    List<Class<?>> getClasses(String packageName) {
        List<File> directories = getDirectoriesForPackage(packageName);

        return directories.stream()
                .map(directory -> getClassesInDirectory(packageName, directory))
                .flatMap(Collection::stream)
                .collect(toList());
    }

    private List<File> getDirectoriesForPackage(String packageName) {
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
        String path = packageName.replace('.', '/');

        Enumeration<URL> resources;
        try {
            resources = classLoader.getResources(path);
        } catch (IOException e) {
            resources = emptyEnumeration();
        }

        List<File> directories = new ArrayList<>();

        while (resources.hasMoreElements()) {
            URL resource = resources.nextElement();
            directories.add(new File(resource.getFile()));
        }
        return directories;
    }

    private List<Class<?>> getClassesInDirectory(String packageName, File directory) {
        Path directoryPath = directory.toPath();

        try {
            return Files.walk(directoryPath)
                    .filter(currentPath -> currentPath.toString().endsWith(JAVA_CLASS_EXTENSION))
                    .map(currentPath -> buildClassCanonicalName(packageName, directoryPath, currentPath))
                    .map(this::convertToClass)
                    .collect(toList());
        } catch (IOException e) {
            throw new ClassFindingException("Unable to read files from the directory: " + directoryPath.toString(), e);
        }
    }

    private Class<?> convertToClass(String path) {
        try {
            return Class.forName(path);
        } catch (ClassNotFoundException e) {
            throw new ClassFindingException("Unable to find class file with name: " + path, e);
        }
    }

    private String buildClassCanonicalName(String packageName, Path directoryPath, Path currentPath) {
        String path = packageName + "." + directoryPath.relativize(currentPath).toString().replace('/', '.');
        return path.substring(0, path.length() - JAVA_CLASS_EXTENSION.length());
    }
}

==> criticizer-0.0.6-sources.jar: pl/michal/grzesiak/criticizer/ClassesProvider.java <==
package pl.michal.grzesiak.criticizer;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.List;

import static java.util.Collections.emptyEnumeration;
import static java.util.stream.Collectors.toList;

class ClassesProvider {

    private static final String JAVA_CLASS_EXTENSION = ".class";

    List<Class<?>> getClasses(String packageName, String classNameSuffix) {
        List<File> directories = getDirectoriesForPackage(packageName);

        return directories.stream()
                .map(directory -> getClassesInDirectory(directory, packageName, classNameSuffix))
                .flatMap(Collection::stream)
                .collect(toList());
    }

    private List<File> getDirectoriesForPackage(String packageName) {
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
        String path = packageName.replace('.', '/');

        Enumeration<URL> resources;
        try {
            resources = classLoader.getResources(path);
        } catch (IOException e) {
            resources = emptyEnumeration();
        }

        List<File> directories = new ArrayList<>();

        while (resources.hasMoreElements()) {
            URL resource = resources.nextElement();
            directories.add(new File(resource.getFile()));
        }
        return directories;
    }

    private List<Class<?>> getClassesInDirectory(File directory, String packageName, String classNameSuffix) {
        Path directoryPath = directory.toPath();

        try {
            return Files.walk(directoryPath)
                    .filter(currentPath -> isJavaClassWithSuffix(classNameSuffix, currentPath))
                    .map(currentPath -> buildClassCanonicalName(packageName, directoryPath, currentPath))
                    .map(this::convertToClass)
                    .collect(toList());
        } catch (IOException e) {
            throw new ClassFindingException("Unable to read files from the directory: " + directoryPath.toString(), e);
        }
    }

    private boolean isJavaClassWithSuffix(String classNameSuffix, Path currentPath) {
        return currentPath.toString().endsWith(classNameSuffix + JAVA_CLASS_EXTENSION);
    }

    private String buildClassCanonicalName(String packageName, Path directoryPath, Path currentPath) {
        String path = packageName + "." + directoryPath.relativize(currentPath).toString().replace('/', '.');
        return path.substring(0, path.length() - JAVA_CLASS_EXTENSION.length());
    }

    private Class<?> convertToClass(String path) {
        try {
            return Class.forName(path);
        } catch (ClassNotFoundException e) {
            throw new ClassFindingException("Unable to find class file with name: " + path, e);
        }
    }
}
